@@ -34,7 +34,6 @@ from urllib.parse import parse_qs, urlencode, urlparse, urlunparse
 import aiohttp
 import chardet
 import requests
-import yaml
 from bs4 import BeautifulSoup
 from lxml import etree
 from requests.structures import CaseInsensitiveDict
@@ -476,17 +475,10 @@ class Requests(BaseRequest):
     def load_cookie(self):
         if self.cookie and Path(self.cookie).exists():
             return self.session.cookies.load(ignore_discard=True, ignore_expires=True)
-            requests.utils.cookiejar_from_dict(yaml.load(open(self.cookie)),
-                                               cookiejar=self.session.cookies,
-                                               overwrite=True)
 
     def save_cookie(self):
         if self.cookie:
             return self.session.cookies.save(ignore_discard=True, ignore_expires=True)
-            yaml.dump(requests.utils.dict_from_cookiejar(self.session.cookies),
-                      open(self.cookie, 'w'),
-                      default_flow_style=False,
-                      allow_unicode=True)
 
     def load_proxy(self):
         if self.proxy:
